:py:mod:`holisticai.pipeline`
============================

.. automodule:: holisticai.pipeline
    :no-members:
    :no-inherited-members:

.. autosummary::
    :nosignatures:
    :template: class.rst
    :toctree: .generated/
    
    Pipeline
